@@ -3,6 +3,7 @@ function (X, clp_ind, clpCon, clpequ, dataset)
 {   
     colx <- dim(X)[2]
     ct <- rep(0, colx)
+    
     if(dim(clpCon$clpRem)[2]!=0){ 
 	ctparam <- 1			 
 	for(i in 1:(dim(clpCon$clpRem)[2])){
@@ -14,15 +15,14 @@ function (X, clp_ind, clpCon, clpequ, dataset)
 			               ct[clpCon$clpRem[clp_ind,i]]  ] *
 			               clpequ[ctparam]
 			ctparam <- ctparam + 1
-	          }
+		  }
 		  else {
 		      cM <- ct[ clpCon$clpMod[clp_ind,i]]
 		      cR <- ct[ clpCon$clpRem[clp_ind,i]]
-		      X[,clpCon$clpMod[clp_ind,i] - cM ] <-
-		      X[,clpCon$clpMod[clp_ind,i] -cM ] +
-		       X[,clpCon$clpRem[clp_ind,i] -cR ] * clpequ[ctparam]
-		      X <-as.matrix(as.matrix(X)[,-(clpCon$clpRem[clp_ind,i] -
-		      cR)])
+	
+	              X[,clpCon$clpMod[clp_ind,i] - cM ] <- X[,clpCon$clpMod[clp_ind,i] -cM ] + X[,clpCon$clpRem[clp_ind,i] -cR ] * clpequ[ctparam]
+		      
+		      X <-as.matrix(as.matrix(X)[,-(clpCon$clpRem[clp_ind,i] -cR)])
 		      ct[ (clpCon$clpRem[clp_ind,i] +1):colx ] <- ct[
 		       (clpCon$clpRem[clp_ind,i] +1):colx ] + 1
 		       ctparam <- ctparam + 1
@@ -40,7 +40,6 @@ function (X, clp_ind, clpCon, clpequ, dataset)
             }
         }
    }
-   
    X
 }
 
