@@ -3,20 +3,22 @@ function (th, parorder, modellist, thetaClasslist, diffchange)
 {
       pcnt <- 1
       for(diffs in diffchange) {
-	  parchange <- modellist[[diffs$dataset[1]]]@parnames
 	  d <- diffs$dataset[1]
+	  parchange <- modellist[[d]]@parnames
+	  
 	  if(diffs$what %in% parchange){
 		 parslot <- getPar(modellist[[d]],
 		 parorder[[pcnt]], th, thetaClasslist[[d]])
 		 pcnt <- pcnt + 1  
-		 if(is.list( slot(thetaClasslist[[d]], diffs$what))) {
+		 if(is.list( slot(modellist[[d]], diffs$what))) {
 			tlist <- list()
 			cnt <- 1
-			for(i in 1:length(slot(thetaClasslist[[d]],diffs$what))){ 
+			
+			for(i in 1:length(slot(modellist[[d]],diffs$what))){ 
 			      	tlist[[i]] <- parslot[cnt:(cnt + 
-					    length(slot(thetaClasslist[[d]], 
+					    length(slot(modellist[[d]], 
 					    diffs$what)[[i]]) -1)]
-				cnt <- cnt + length(slot(thetaClasslist[[d]], 
+				cnt <- cnt + length(slot(modellist[[d]], 
 				diffs$what)[[i]])
 			}
 			parslot <- tlist
