@@ -10,12 +10,15 @@ function ()
         fixed = "list", clp0 = "list", makeps = "character", 
         clpequspec = "list", lclp0 = "logical", lclpequ = "logical", 
         title = "character", mhist = "list", datCall = "list", 
-        dscalspec = "list", 
+        dscalspec = "list", mvecind = "vector", 
         drel = "vector", clpequ = "vector", scalx = "numeric", 
         prel = "vector", prelspec = "list", fvecind = "vector", 
-        pvecind = "vector", iter = "numeric", 
+        pvecind = "vector", nvecind = "vector",
+	iter = "numeric", free = "list",
         clpCon = "list", ncomp = "numeric", clpdep = "logical", 
-	inten = "matrix", positivepar="vector"), 
+	inten = "matrix", positivepar="vector", constrained ="list", 
+	clinde = "list", chinde = "list", highcon = "vector", 
+	lowcon = "vector", datafile = "character"), 
         prototype = list(psi.df = matrix(), psi.weight = matrix(), 
             x = vector(), nt = integer(), x2 = vector(), nl = integer(), 
             C2 = matrix(), E2 = matrix(), sigma = numeric(), 
@@ -24,11 +27,13 @@ function ()
             weightsmooth = list(), fixed = list(), clp0 = list(), 
             clpequspec = list(), clpCon = list(), lclp0 = logical(), 
             lclpequ = logical(), makeps = character(), title = character(), 
-            mhist = list(), datCall = list(), 
-            dscal = list(), drel = vector(), 
+            mhist = list(), datCall = list(), nvecind = vector(), 
+            dscal = list(), drel = vector(),  mvecind = vector(),
             scalx = 1, prel = vector(), prelspec = list(), fvecind = vector(), 
-            pvecind = vector(), clpequ = vector(), 
+            pvecind = vector(), clpequ = vector(), free = list(),
             iter = 1, ncomp = numeric(), clpdep = logical(),inten = matrix(), 
-	    parnames=vector(), positivepar=vector()))
+	    parnames=vector(), positivepar=vector(), constrained =list(), 
+	    clinde = list(), chinde = list(), highcon = vector(), 
+	    lowcon = vector(), datafile = ""))
 }
 
