@@ -7,6 +7,7 @@ specpar = "list",
 seqmod = "logical", 
 irf = "logical", 
 mirf = "logical", 
+reftau = "numeric",
 cohcol = "numeric",
 measured_irf = "vector", 
 convalg = "numeric",
@@ -15,6 +16,7 @@ irfpar = "vector",
 cohirf = "vector",
 dispmu = "logical", 
 dispmufun = "character", 
+anipar = "vector",
 parmu = "list",
 disptau = "logical", 
 disptaufun = "character", 
@@ -22,6 +24,7 @@ partau = "vector",
 fullk = "logical",
 kmat = "array", 
 jvec = "vector", 
+anispec = "list",
 ncolc = "vector", 
 kinscal = "vector", 
 kmatfit = "array", 
@@ -42,11 +45,14 @@ measured_irf = vector(),
 convalg = 1, 
 cohirf = vector(),
 irffun = "gaus", 
+anispec = list(),
 irfpar = vector(),  
 dispmu = FALSE, 
 dispmufun = "poly", 
 parmu = list(),
+anipar = vector(), 
 disptaufun = "poly", 
+reftau = 0,
 specpar = list(), 
 cohcol = 0,
 partau = vector(),
