@@ -1,13 +1,5 @@
 "plotKinBreakDown" <-
 function (multimodel, multitheta, plotoptions) { 
-
-    ## breakdown assumed to have following elements:
-    ## character vector "type", can be "ind" "abs", defaults to "ind", 
-    ## for multiple datasets this will plot ind 1 in all datasets if
-    ## superimpose > 1 -- this could be bad for different x2-ranges   
-    ## numeric vector "plot" of wavelengths to plot 
-    ##                       OR wavelength indices to plot
-    ##  character vector "from", dataset indices (defaults to all) 
     get(getOption("device"))()
     plotrow<-length(plotoptions@breakdown$plot) 
     plotcol<-1
@@ -20,9 +12,6 @@ function (multimodel, multitheta, plotoptions) {
     m <- multimodel@modellist   
     t <- multitheta   
     res <- multimodel@fit@resultlist
-    ## is x2 decreasing? assume answer same for all datasets 
-    x2_decr <- if(m[[1]]@x2[1] < m[[1]]@x2[m[[1]]@nl]) FALSE
-	       else TRUE
     allx2 <- allx <- vector() 
     pl <- plotoptions@breakdown$plot
     if(length(plotoptions@breakdown$tol) == 0)
@@ -61,7 +50,7 @@ function (multimodel, multitheta, plotoptions) {
 	  allx2 <- append(allx2, m[[i]]@x2) 
 	  allx <- append(allx, m[[i]]@x)
     }
-    allx2 <- sort(unique(allx2), decreasing = x2_decr) 
+    allx2 <- sort(unique(allx2)) 
     allx <- sort(unique(allx))
     xmax <- max(allx)
     xmin <- min(allx)
@@ -98,7 +87,7 @@ function (multimodel, multitheta, plotoptions) {
 			      irfpar=irfvec,
 			      irf=m[[i]]@irf, seqmod=m[[i]]@seqmod,
 			      fullk=m[[i]]@fullk, kmat=m[[i]]@kmat,
-			      jvec=m[[i]]@jvec, dscalspec=m[[i]]@dscalspec,
+			      jvec=t[[i]]@jvec, dscalspec=m[[i]]@dscalspec,
 			      drel=t[[i]]@drel, cohspec=m[[i]]@cohspec, coh =
 			      t[[i]]@coh, lamb=breakl, dataset=i, 
 			      cohirf = cohirf,  mirf = m[[i]]@mirf, 
@@ -106,7 +95,11 @@ function (multimodel, multitheta, plotoptions) {
 			      speckin2 = m[[i]]@speckin2, 
 			      usekin2 = m[[i]]@usekin2, 
 			      kinpar2 = t[[i]]@kinpar2, 
-			      kin2scal = t[[i]]@kin2scal), 
+			      kin2scal = t[[i]]@kin2scal, 
+			      reftau = m[[i]]@reftau, 
+			      anispec = m[[i]]@anispec, 
+			      anipar = t[[i]]@anipar, 
+			      cohcol = m[[i]]@cohcol), 
 			      breakl, m[[i]]@clpCon,
 			      t[[i]]@clpequ, dataset = i)
 
@@ -174,7 +167,8 @@ function (multimodel, multitheta, plotoptions) {
 
 			matlinlogplot(m[[i]]@x, resPList[[i]], mu=mu,
 			alpha=plotoptions@linrange, add = !newplot, type =
-			"l", lty=i, ylab ="amplitude", xlab=plotoptions@xlab,
+			"l", lty=i, ylab =plotoptions@ylab, 
+			xlab=plotoptions@xlab,
 			ylim = ylim, xlim = c(xmin, xmax),
 			main = m[[i]]@x2[breakl])
 	
@@ -192,13 +186,23 @@ function (multimodel, multitheta, plotoptions) {
 	  }
         }
 	if(length(plotoptions@title) != 0){
-	mtext(plotoptions@title, side=3,outer=TRUE,line=1) 
-	par(las=2)
-	}		
+			tit <- plotoptions@title
+			if(plotoptions@addfilename) tit <- paste(tit,m[[i]]@datafile)
+    }
+    else {
+                        tit <- ""
+		        if(plotoptions@addfilename) tit <- paste(tit, m[[i]]@datafile)
+    }
+    mtext(tit, side = 3, outer = TRUE, line = 1)
+    par(las = 2)		
              # MAKE PS
        if(dev.interactive() && length(plotoptions@makeps) != 0) {
-		dev.print(device=postscript, 
-		file=paste(plotoptions@makeps, "_breakdown.ps", sep=""))
+		if(plotoptions@output == "pdf")
+				      pdev <- pdf 
+		else  pdev <- postscript		
+		dev.print(device=pdev, 
+		file=paste(plotoptions@makeps, "_breakdown.", 
+		plotoptions@output, sep=""))
        }
     
 }
