@@ -4,9 +4,7 @@ function(t, plotoptions, multimodel)
 	get(getOption("device"))()
 	resultlist <- multimodel@fit@resultlist
 	sumonls <-  multimodel@fit@nlsres$sumonls
-	m <- multimodel@modellist 
-	par(mfrow=c(1,2))
-	par(oma = c(0,0,4,0))
+	par(mfrow=c(1,2), mar=c(5,2,2,2))
 	plotKinSpec(multimodel, t, plotoptions, newplot=FALSE, 
 	kinspecerr = plotoptions@kinspecerr)
 	plotEst(multimodel, plotoptions) 
@@ -16,8 +14,12 @@ function(t, plotoptions, multimodel)
             par(las = 2)
         }
 	if (dev.interactive() && length(plotoptions@makeps) != 0) {
-            dev.print(device = postscript, file = paste(plotoptions@makeps, 
-                "_kinspecrates.ps", sep = ""))
+	   if(plotoptions@output == "pdf")
+				 pdev <- pdf 
+	   else  pdev <- postscript
+
+            dev.print(device = pdev, file = paste(plotoptions@makeps, 
+                "_kinspecrates.",plotoptions@output, sep = ""))
         }
 
 }
